<?php
/**
* Register API Init - REST Pre Callback
*
* Description: Using the REST Pre callback to switch the blog based on the content of the domain
* @since 1.0.0
*
* @param none
* @return type boolean Switching of Site information for the Rest API Url
*/
add_action('rest_api_init', 'spnow_register_rest_pre_callback');
function spnow_register_rest_pre_callback() {
  global $wpdb;
  try {
    $http_host = sanitize_url($_SERVER['HTTP_HOST']);
    $args = array(
          'domain' => $http_host
    );
    $results = get_sites($args);
    if ($results) {
      $result = $results[0];
      $blog_id = sanitize_text_field($_GET['blog_id']);
      if (is_numeric($blog_id)) {
        $wpdb->set_blog_id($blog_id, 1);
      } else {
        $wpdb->set_blog_id(1, 1);
      }
    }
  } catch (Error $e) {
    return false;
  }
}

/**
* Register API Init - Register REST Route - Network Sites
*
* Description: Registering a REST Route for ServicePress blogs to pull back a list of Network sites
* @since 1.0.0
*
* @param none
* @return type Array Return an array of Blogs available from Network Sites
*/
add_action('rest_api_init', 'spnow_register_network_blogs');
function spnow_register_network_blogs() {
  register_rest_route(SPNOW_SERVICEPRESS_REST_BASE.'/'.SPNOW_SERVICEPRESS_API_VERSION, 'blogs', [
    'methods' => 'GET',
    'callback' => 'spnow_get_network_blog_sites'
  ]);
};
function spnow_get_network_blog_sites() {
  try {
    $args = array(
      'public'    => 1, // I only want the sites marked Public
      'archived'  => 0,
      'mature'    => 0,
      'spam'      => 0,
      'deleted'   => 0,
    );

    $sites = get_sites( $args );
    return $sites;
  } catch (Error $e) {
    return false;
  }

}
?>
